<?php

/**
 * Callback function to export language data in csv.
 */
function migration_audit_languages_data() {

  $languages = migration_get_languages();

  // Output into a csv file
  $filename = 'languages.csv';
  header('Content-Type: text/csv; charset=utf-8');
  header('Content-Disposition: attachment; filename=' . $filename);
  $csv_file = fopen("php://output", "w");

  fputcsv($csv_file, $languages['header']);

  foreach($languages['data'] as $key => $data) {
    if (is_object($data)) {
      $data = (array)$data;
    }

    if (!empty($data)) {
      fputcsv($csv_file, $data, ',', '"');
    }
  }

  fclose($csv_file);
  exit();
}

/**
 * Function to get data from database.
 */
function migration_get_languages() {
  $header = [
    'language' => 'Language Code',
    'name' => 'Name',
    'native' => 'Native',
    'direction' => 'Direction',
    'enabled' => 'Enabled',
    'plurals' => 'Plurals',
    'formula' => 'Formmula',
    'domain' => 'Domain',
    'prefix' => 'Prefix',
    'weight' => 'Weight',
    'default' => 'Default',
  ];

  $result = [];
  if (module_exists('locale')) {
    $languages = language_list();
    $default_lang = variable_get('language_default');
    $default_language = $default_lang->language;

    foreach ($languages as $key => $language_obj) {
      $result[$key] = [
        'language' => $key,
        'name' => $language_obj->name,
        'native' => $language_obj->native,
        'direction' => $language_obj->direction,
        'enabled' => $language_obj->enabled,
        'plurals' => $language_obj->plurals,
        'formula' => $language_obj->formula,
        'domain' => $language_obj->domain,
        'prefix' => $language_obj->prefix,
        'weight' => $language_obj->weight,
      ];

      $result[$key]['default'] = '';
      if ($key == $default_language) {
        $result[$key]['default'] = 'Yes';
      }
    }
  }

  return array('header' => $header, 'data' => $result);
}

/**
 * Function to return file data and column headers.
 */
function export_languages_entity() {
  $content_type = migration_get_languages();
  $count = count($content_type['header']);
  $content_data = array(
    array_values($content_type['header']),
    array_values($content_type['header'])
  );
  foreach ($content_type['data'] as $data_obj) {
    if (is_object($data_obj)) {
      $data_obj = (array)$data_obj;
    }
    array_push($content_data, array_values($data_obj));
  }

  return array($content_data, $count);
}
